#ifndef NT2_INCLUDE_FUNCTIONS_EPS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_EPS_HPP_INCLUDED

#include <nt2/ieee/include/functions/eps.hpp>

#endif
